
varying lowp vec4 v_color;
varying lowp vec2 v_texCoord;

uniform sampler2D u_texture;
uniform sampler2D u_texture1;
uniform sampler2D u_texture2;
uniform float u_materialShininess;
uniform ivec2 u_textureSize; 
 
void main() {  
	// no custom uniform, use u_materialShininess to indicate if the blur is vertical (0) or horizontal (1)
	lowp vec2 blurDirection = mix(vec2(1.0, 0.0), vec2(0.0, 1.0), u_materialShininess);
	lowp vec2 texOffset = blurDirection / vec2(u_textureSize.x, u_textureSize.y);
	const lowp int blurSize = 8;	// Hard coded for the fog of war
	const lowp int numBlurPixelsPerSide = blurSize / 2; 
	const highp float sigma = 4.0; 	// The sigma value for the gaussian function: higher value means more blur
                        // A good value for 9x9 is around 3 to 5
                        // A good value for 7x7 is around 2.5 to 4
                        // A good value for 5x5 is around 2 to 3.5
	const highp float pi = 3.14159265;
	  
	// Incremental Gaussian Coefficent Calculation (See GPU Gems 3 pp. 877 - 889)
	highp vec3 incrementalGaussian;
	incrementalGaussian.x = 1.0 / (sqrt(2.0 * pi) * sigma);
	incrementalGaussian.y = exp(-0.5 / (sigma * sigma));
	incrementalGaussian.z = incrementalGaussian.y * incrementalGaussian.y;
 
	// Take the central sample first...
	lowp vec4 color = texture2D(u_texture, v_texCoord.st);
	highp float avgValue = color.a * incrementalGaussian.x;

	highp float coefficientSum = incrementalGaussian.x;
	incrementalGaussian.xy *= incrementalGaussian.yz;
 
	// Go through the samples on each side (horizontal or vertical)
	for (lowp int i = 1; i <= numBlurPixelsPerSide; i++) { 
		lowp vec2 offset = float(i) * texOffset;
		avgValue += texture2D(u_texture, v_texCoord.st - offset).a * incrementalGaussian.x;         
		avgValue += texture2D(u_texture, v_texCoord.st + offset).a * incrementalGaussian.x;         
		coefficientSum += 2.0 * incrementalGaussian.x;
		incrementalGaussian.xy *= incrementalGaussian.yz;
	}
 
	gl_FragColor.rgb = color.rgb;
	gl_FragColor.a = avgValue / coefficientSum;
}
